@@ -4,11 +4,11 @@ use all4art_authservice_domain::{public_key::PublicKey, clear_text_password::{Cl
 
 pub struct LoginQuery { 
     _public_key: PublicKey,
-    _clear_text_password: Arc<dyn ClearTextPassword>
+    _clear_text_password: Arc<dyn ClearTextPassword + Send + Sync>
 }
 
 impl LoginQuery { 
-    pub fn new(public_key: PublicKey, clear_text_password: Arc<dyn ClearTextPassword>) -> Self { 
+    pub fn new(public_key: PublicKey, clear_text_password: Arc<dyn ClearTextPassword + Send + Sync>) -> Self { 
        LoginQuery{_public_key: public_key, _clear_text_password: clear_text_password}
     }
 
