@@ -8,4 +8,8 @@ impl LoginQueryResult {
     pub fn new(token: Token) -> Self { 
        LoginQueryResult {_token: token}
     }
+
+    pub fn token(&self) -> &Token { 
+        &self._token
+    }
 }
